<?php

namespace Modules\St\Http\Controllers;

use Exception;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Modules\St\Entities\GLPosting;
use Modules\St\Entities\GroupLevel1;
use Modules\St\Entities\GroupLevel2;
use Modules\St\Entities\GroupLevel3;
use Modules\St\Entities\Product;
use Modules\St\Entities\ProductType;

class ProductController extends Controller
{
    /**
     * Display a listing of the resource.
     * @return Renderable
     */
    public function index()
    {
        return view('st::index');
    }

    /**
     * Show the form for creating a new resource.
     * @return Renderable
     */
    public function create()
    {
        return view('st::create');
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Renderable
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Show the specified resource.
     * @param int $id
     * @return Renderable
     */
    public function show($id)
    {
        return view('st::show');
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Renderable
     */
    public function edit($id)
    {
        return view('st::edit');
    }



    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Renderable
     */
    public function destroy($id)
    {
        //
    }


    public function settings()
    {
        try {
            $groupLevel1 = GroupLevel1::all();
            $productType = ProductType::all();
            $glAnalysis = GLPosting::all();
            $settings = [
                "grouplevel1" => $groupLevel1,
                "productType" => $productType,
                "glAnalysis" => $glAnalysis,
            ];
            $responseBody = $this->responseBody(true, "Settings", "all", $settings);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "Settings", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }



    public function save(Request $request)
    {
        try {
            $productId = $request->get("productId");
            $productName = $request->get("productName");
            $description = $request->get("description");
            $unitOfMesurement = $request->get("unitOfMesurement");
            $sku = $request->get("sku");
            $grouplevel1 = $request->get("grouplevel1");
            $groupLevel2 = $request->get("groupLevel2");
            $groupLevel3 = $request->get("groupLevel3");
            $reorderLevel = $request->get("reorderLevel");
            $reorderQuantity = $request->get("reorderQuantity");
            if (is_null($reorderQuantity)) {
                $reorderQuantity = 0;
            }
            $productType = $request->get("productType");
            $glAnalysis = $request->get("glAnalysis");
            $note = $request->get("note");
            $sms = $request->get("sms");
            $email = $request->get("email");
            $notification = $request->get("notification");
            $active = $request->get("active");

            $product =  new Product();
            $product->product_id = $productId;
            $product->product_name = $this->isEmpty($productName);
            $product->product_description = $this->isEmpty($description);
            $product->uom_id = $this->isEmpty($unitOfMesurement);
            $product->sku = $this->isEmpty($sku);
            $product->group_id_level_1 = $this->isEmpty($grouplevel1);
            $product->group_id_level_2 = $this->isEmpty($groupLevel2);
            $product->group_id_level_3 = $this->isEmpty($groupLevel3);
            $product->reorder_level = $this->isEmpty($reorderLevel);
            $product->reorder_quantity = $this->isEmpty($reorderQuantity);
            $product->product_type_id = $this->isEmpty($productType);
            $product->gl_analysis_id = $this->isEmpty($glAnalysis);
            $product->sms_alert = $this->isBoolean($sms);
            $product->email_alert = $this->isBoolean($email);
            $product->notification = $this->isBoolean($notification);
            $product->status = $this->isBoolean($active);
            $product->image_path = NULL;
            $product->notes = $note;
            $product->save();

            $responseBody = $this->responseBody(true, "Product", "save", NULL);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "Product", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }



    public function update(Request $request, $id)
    {
        try {
            $productId = $request->get("productId");
            $productName = $request->get("productName");
            $description = $request->get("description");
            $unitOfMesurement = $request->get("unitOfMesurement");
            $sku = $request->get("sku");
            $grouplevel1 = $request->get("grouplevel1");
            $groupLevel2 = $request->get("groupLevel2");
            $groupLevel3 = $request->get("groupLevel3");
            $reorderLevel = $request->get("reorderLevel");
            $reorderQuantity = $request->get("reorderQuantity");
            if(is_null($reorderQuantity)){
                $reorderQuantity = 0;
            }
            $productType = $request->get("productType");
            $glAnalysis = $request->get("glAnalysis");
            $note = $request->get("note");
            $sms = $request->get("sms");
            $email = $request->get("email");
            $notification = $request->get("notification");
            $active = $request->get("active");

            $product = Product::find($id);
            //$product->product_id = $productId;
            $product->product_name = $this->isEmpty($productName);
            $product->product_description = $this->isEmpty($description);
            $product->uom_id = $this->isEmpty($unitOfMesurement);
            $product->sku = $this->isEmpty($sku);
            $product->group_id_level_1 = $this->isEmpty($grouplevel1);
            $product->group_id_level_2 = $this->isEmpty($groupLevel2);
            $product->group_id_level_3 = $this->isEmpty($groupLevel3);
            $product->reorder_level = $this->isEmpty($reorderLevel);
            $product->reorder_quantity = $this->isEmpty($reorderQuantity);
            $product->product_type_id = $this->isEmpty($productType);
            $product->gl_analysis_id = $this->isEmpty($glAnalysis);
            $product->sms_alert = $this->isBoolean($sms);
            $product->email_alert = $this->isBoolean($email);
            $product->notification = $this->isBoolean($notification);
            $product->status = $this->isBoolean($active);
            $product->image_path = NULL;
            $product->notes = $note;
            $product->update();

            $responseBody = $this->responseBody(true, "Product", "updated", NULL);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "Product", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }




    public function groupLevel2($id)
    {
        try {
            $groupLevel2 = GroupLevel2::where('grp_lvl_1_for_id', '=', $id)->get();
            $settings = [
                "groupLevel2" => $groupLevel2,
            ];
            $responseBody = $this->responseBody(true, "GroupLevel2", "all", $settings);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "GroupLevel2", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }


    public function groupLevel3($id1, $id2)
    {
        try {
            $groupLevel3 = GroupLevel3::where([['grp_lvl_1_for_id', '=', $id1], ['grp_lvl_2_for_id', '=', $id2]])->get();
            $settings = [
                "groupLevel3" => $groupLevel3,
            ];
            $responseBody = $this->responseBody(true, "GroupLevel3", "all", $settings);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "GroupLevel3", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }


    public function allProducts()
    {
        try {
            $products = Product::all();
            $responseBody = $this->responseBody(true, "Products", "all", $products);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "Products", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }


    public function isDuplicate($id)
    {
        $product = Product::where('product_id', '=', $id)->first();
        if ($product === null) {
            return "false";
        }
        return "true";
    }


    protected function isBoolean($value)
    {

        if ($value == "true") {
            return true;
        }
        return false;
    }

    protected function isEmpty($val)
    {

        if (is_null($val)) {
            return NULL;
        }
        return $val;
    }


    public function getProduct($id)
    {
        try {
            $product = Product::find($id);
            $responseBody = $this->responseBody(true, "Product", "get", $product);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "Product", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }



    public function delete($id)
    {
        try {
            $product = Product::find($id);
            $delete = $product->delete();
            $responseBody = $this->responseBody(true, "Product", "deleted", $delete);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "Product", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }


    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
