$(document).ready(function () {
    $('#tblSupplier').DataTable({
        "scrollX": true,
        "order": [],
        "columns": [
            { "data": "id" },
            { "data": "name" },
            { "data": "edit", className: "edit" },
            { "data": "view", className: "view" },
            { "data": "delete", className: "delete" },
        ],
        columnDefs: [
            { width: 100, targets: 0 },
            { width: 40, targets: 2 },
            { width: 40, targets: 3 },
            { width: 40, targets: 4 },
        ],
    });

    allSuppliers();
});


function allSuppliers() {
    $.ajax({
        type: "GET",
        url: "/st/supplierList/allSuppliers",
        async: false,
        processData: false,
        contentType: false,
        async: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () {

        },
        success: function (response) {
            console.log(response);
            if (response.data.success) {
                var result = response.data.result;
                appendTableRow(result);

            } else {
                showErrorMessage();
            }

        },
        error: function (error) {
            console.log(error);
            showErrorMessage();

        },
        complete: function () {

        }

    });
}





function appendTableRow(result) {

    var data = [];
    for (i = 0; i < result.length; i++) {


        var supplier_id = result[i]['supplier_id'];
        var supplier_name = result[i]['supplier_name'];
        var string_id = "'" + supplier_id + "'";

        data.push({
            "id": supplier_id,
            "name": supplier_name,
            "edit": '<button class="btn btn-primary" onclick="edit(' + string_id + ')"><i class="fa fa-pencil-square-o" aria-hidden="true"></i></button>',
            "view": '<button class="btn btn-success" onclick="view(' + string_id + ')"><i class="fa fa-eye" aria-hidden="true"></i></i></button>',
            "delete": '<button class="btn btn-danger" onclick="_delete(' + string_id + ')"><i class="fa fa-trash" aria-hidden="true"></i></button>',
        });

    }



    var table = $('#tblSupplier').DataTable();
    table.clear();
    table.rows.add(data).draw();

}



function edit(id) {
    location.href = "/st/create_supplier?id=" + id + "&action=edit";
}

function view(id) {
    location.href = "/st/create_supplier?id=" + id + "&action=view";
}

function _delete(id) {

    $.ajax({
        type: 'DELETE',
        url: '/st/supplier/delete/' + id,
        data: {
            _token: $('input[name=_token]').val()
        },
        timeout: 800000,
        beforeSend: function () {

        },
        success: function (response) {
            console.log(response);
            if (response.data.success) {
                showSuccessMessage('Supplier has been deleted successfully...');
                allSuppliers();

            } else {
                showErrorMessage();
            }

        },
        error: function (error) {
            console.log(error);
            showErrorMessage();
        },
        complete: function () {

        }

    });
}



/**
* showSuccessMessage
* This function is used to show success message.
* @param message This is the paramter to require message content
*/
function showSuccessMessage(message) {
    toastr.success(message);
}


/**
* showWarningMessage
* This function is used to show warning message.
* @param message This is the paramter to require message content
*/
function showWarningMessage(message) {
    toastr.warning(message);
}



/**
* showErrorMessage
* This function is used to show error message.
* @param message This is the paramter to require message content
*/
function showErrorMessage() {
    toastr.error('Something went wrong');
}